==> spic-0.0.4.tar.gz: spic-0.0.4/COVERAGE.md <==
| Name                             |   Stmts |    Miss |   Cover |                                                                        Missing |
| -------------------------------- | ------: | ------: | ------: | -----------------------------------------------------------------------------: |
| src/spic/\_\_init\_\_.py         |       0 |       0 |    100% |                                                                                |
| src/spic/app.py                  |     128 |      35 |     73% | 58-59, 65-72, 85-92, 100-132, 135, 143, 185, 188, 191, 194, 197, 200, 203, 209 |
| src/spic/core_exceptions.py      |      11 |       1 |     91% |                                                                             13 |
| src/spic/defaults.py             |       4 |       0 |    100% |                                                                                |
| src/spic/emit.py                 |      22 |       3 |     86% |                                                                      39-40, 45 |
| src/spic/encoders.py             |      54 |      11 |     80% |                                                   37, 45, 54, 61, 63-66, 82-85 |
| src/spic/enums.py                |       9 |       0 |    100% |                                                                                |
| src/spic/exceptions.py           |      41 |       5 |     88% |                                                                      32-35, 63 |
| src/spic/func_handler.py         |      97 |      16 |     84% |                34, 49-50, 52, 56-57, 61, 64, 83-86, 90, 129, 138, 140-141, 146 |
| src/spic/inspect.py              |      50 |       5 |     90% |                                                                  14, 20, 72-74 |
| src/spic/middleware.py           |      20 |       6 |     70% |                                                                      15, 24-28 |
| src/spic/openapi/\_\_init\_\_.py |       4 |       0 |    100% |                                                                                |
| src/spic/openapi/models.py       |     157 |       0 |    100% |                                                                                |
| src/spic/openapi/utils.py        |       8 |       0 |    100% |                                                                                |
| src/spic/params/\_\_init\_\_.py  |      11 |       0 |    100% |                                                                                |
| src/spic/params/params.py        |      88 |      12 |     86% |                                          29-32, 39, 56, 59, 64, 72, 76-77, 101 |
| src/spic/request.py              |      33 |       0 |    100% |                                                                                |
| src/spic/responses.py            |      41 |       2 |     95% |                                                                          84-85 |
| src/spic/routing.py              |     109 |      15 |     86% |                    67-68, 102, 123-133, 146, 167, 170, 173, 176, 179, 182, 185 |
| src/spic/types.py                |      29 |       8 |     72% |                                                                  29, 33-40, 47 |
| src/spic/utils.py                |      34 |       2 |     94% |                                                                         37, 65 |
| **TOTAL**                        | **950** | **121** | **87%** |                                                                                |

==> spic-0.0.5.tar.gz: spic-0.0.5/COVERAGE.md <==
| Name                             |   Stmts |    Miss |   Cover |                                                                        Missing |
| -------------------------------- | ------: | ------: | ------: | -----------------------------------------------------------------------------: |
| src/spic/\_\_init\_\_.py         |       1 |       0 |    100% |                                                                                |
| src/spic/app.py                  |     128 |      35 |     73% | 58-59, 65-72, 85-92, 100-132, 135, 143, 185, 188, 191, 194, 197, 200, 203, 209 |
| src/spic/defaults.py             |       4 |       0 |    100% |                                                                                |
| src/spic/emit.py                 |      22 |       3 |     86% |                                                                      39-40, 45 |
| src/spic/encoders.py             |      83 |      23 |     72% |                17-18, 21-22, 26-31, 51, 59, 67-68, 73, 89, 96, 98-101, 118-121 |
| src/spic/enums.py                |      12 |       0 |    100% |                                                                                |
| src/spic/exception_handlers.py   |      11 |       1 |     91% |                                                                             13 |
| src/spic/exceptions.py           |      41 |       5 |     88% |                                                                      32-35, 63 |
| src/spic/func_handler.py         |      97 |      16 |     84% |                34, 49-50, 52, 56-57, 61, 64, 83-86, 90, 129, 138, 140-141, 146 |
| src/spic/inspect.py              |      50 |       5 |     90% |                                                                  14, 20, 72-74 |
| src/spic/middleware.py           |      20 |       6 |     70% |                                                                      15, 24-28 |
| src/spic/openapi/\_\_init\_\_.py |       4 |       0 |    100% |                                                                                |
| src/spic/openapi/models.py       |     157 |       0 |    100% |                                                                                |
| src/spic/openapi/utils.py        |       8 |       0 |    100% |                                                                                |
| src/spic/params/\_\_init\_\_.py  |      11 |       0 |    100% |                                                                                |
| src/spic/params/params.py        |      88 |      12 |     86% |                                          29-32, 39, 56, 59, 64, 72, 76-77, 101 |
| src/spic/request.py              |      33 |       0 |    100% |                                                                                |
| src/spic/responses.py            |      41 |       2 |     95% |                                                                          84-85 |
| src/spic/routing.py              |     109 |      15 |     86% |                    67-68, 102, 123-133, 146, 167, 170, 173, 176, 179, 182, 185 |
| src/spic/types.py                |      36 |      12 |     67% |                                                       29, 33-40, 47, 52, 56-59 |
| src/spic/utils.py                |      34 |       2 |     94% |                                                                         37, 65 |
| **TOTAL**                        | **990** | **137** | **86%** |                                                                                |
